..
    Copyright 2013 Hewlett-Packard Development Company, L.P.

    Licensed under the Apache License, Version 2.0 (the "License"); you may
    not use this file except in compliance with the License. You may obtain
    a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
    License for the specific language governing permissions and limitations
    under the License.

.. _related:

.. index::
    double: related; brief

=============
Related Links
=============

* `Bug Tracker`_
* `Blueprints`_
* `Git`_

================
Related Projects
================

* `Chef Cookbook`_
* `Debian Packaging`_
* `Launchpad PPA`_
* `Sample Plugin`_
* `Symantec Nova Plugin`_
* `Symantec Neutron Plugin`_


.. _Bug Tracker: https://bugs.launchpad.net/designate
.. _Blueprints: https://blueprints.launchpad.net/designate
.. _Git: https://opendev.org/openstack/designate
.. _Chef Cookbook: https://github.com/moniker-dns/designate-cookbook
.. _Debian Packaging: https://github.com/moniker-dns/debian-designate
.. _Launchpad PPA: https://launchpad.net/~designate-ppa/+archive/havana
.. _Sample Plugin: https://github.com/kiall/designate-ext-samplehandler
.. _Symantec Nova Plugin: https://github.com/Symantec/nova-designate-dns-plugin
.. _Symantec Neutron Plugin: https://github.com/Symantec/neutron-designate-fip-plugin
